function out = plotnullclinesnetwork1

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%In this script we will plot the two isoclines of the system              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% Define parameters

clear all;
close all;

%format long;

global arac ca gfp camp synt_rates Karac Kca Kpca kcat degr_rates diss_rates ...
    p_basal arabinose crp eta n

%index for the matrix

arac=1;
ca=2;
gfp=3;
camp=4;

%synthesis rates

synt_rates=zeros(3,1);%M.L-1.min-1

%equation of evolution of arac:
%crpcamp -> arac
%darac=synt_rates(arac)*crpcamp^n/(Karac^n+crpcamp^n) hill function
% -degr_rates(arac)*s(arac)                           degradation
%+p_basal(arac)                                        basal productio,

synt_rates(arac)=12*10^(-8); 

%equation of evolution of ca:
%crpcamp and aracet -> ca
%dca=synt_rates(ca)*crpcamp^n/(Kpca^n +
%crpcamp^n)*aracet^n/(Kca^n+aracet^n)        product of hill functions
%-degr_rates(ca)*s(ca)                        degradation
%+p_basal(ca)                                 basal production

synt_rates(ca)=2*10^(-9);

%threshold

Karac=0.3*10^(-6);%mol.L-1 %correspond to the activation of arac by crpcam
Kca=0.5*10^(-5);%corresponds to the activation of ca by arac
Kpca=0.6*10^(-6);%corresponds to the activation of ca by crpcamp 

%catalyse coefficient
%ca+atp -> ca atp -> ca +camp
%CAMP=kcat*s(ca)/degr_rates(camp)                catalyse procution by ca
%+eta*CAMPi/degr_rates(camp)                     camp out initial

kcat=6*135;%min-1


%Dissociation rates

diss_rates=zeros(2,1);%M-1.L.min-1

%here is the dissociation coefficient in the complexation of crp with camp
%camp + crp -> crpcamp
%crpcamp=crp*CAMP/(diss_rates(camp)+CAMP)
diss_rates(camp)=10^(-5);


%here is the dissociation coefficient of the complexation of arabinose 
% arac + arabinose -> aracet
%with arac
%aracet=s(arac)/(1+diss_rates(arac)/arabinose)
diss_rates(arac)=2*10^(-13);


%export/degradation rates

degr_rates=zeros(4,1);%min-1

degr_rates(arac)=6*10^(-3);
degr_rates(ca)=6*10^(-3); % value Elise: 10^(-3)
degr_rates(gfp)=6*10^(-3);
degr_rates(camp)=2.1;

%basal coefficients

p_basal=zeros(2,1);%M.L.min-1

p_basal(arac)=12*10^(-11);
p_basal(ca)=2*10^(-12);


%constant production

arabinose=10^(-4);%M.L-1
crp=10^(-6);

%quorum sensing coefficient %min-1
eta=6*10^(-1);

%hill cooperativity

n=1.5; % value Elise: 1

%concentration range variables

max_conc=zeros(2,1); %M

max_conc(ca)=1.5*(synt_rates(ca)+p_basal(ca))/degr_rates(ca);%10^(-6);
max_conc(arac)=1.5*(synt_rates(arac)+p_basal(arac))/degr_rates(arac);%10^(-6);

%% Name equations

daracdt = @odeArac;
dcyadt = @odeCya;


%% Define and plot nullclines


for j = 5:7 %iterate over external camp concentrations

    campext = 10^(-j);
    daracdtcamp = @(arac,cya) daracdt(arac,cya,campext);
    dcyadtcamp = @(arac,cya) dcyadt(arac,cya,campext);

    % plot nullclines

    figure;

    ez1=ezplot(daracdtcamp,[0,max_conc(arac),0,max_conc(ca)]);
    set(ez1,'Color','m');
    hold on;
    ez2=ezplot(dcyadtcamp,[0,max_conc(arac),0,max_conc(ca)]);
    set(ez2,'Color','b'); 
    title('Isoclines of Cya and AraC');
    hold off;

   
end

%% Define differential equations

    function dadt = odeArac(a,c,cext)

        campint = kcat*c/degr_rates(camp)+ cext*eta/degr_rates(camp);
        crpcamp = ((diss_rates(camp) + campint + crp) ...
            - sqrt((diss_rates(camp) + campint + crp).^2 -4 * campint .* crp))/2;

        %crpcamp=campint;
        
        dadt = synt_rates(arac)*(crpcamp.^n./(Karac.^n+crpcamp.^n)) ...
            + p_basal(arac) - degr_rates(arac)*a;
    end

    function dcdt = odeCya(a,c,cext)

        campint = kcat*c/degr_rates(camp)+ cext*eta/degr_rates(camp);
        crpcamp = ((diss_rates(camp) + campint + crp)...
            - sqrt((diss_rates(camp) + campint + crp).^2 -4 * campint .* crp))/2;

        %crpcamp=campint;

        aracet=a./(1+diss_rates(arac)/arabinose);
        %aracet=arabinose;

        dcdt = synt_rates(ca)*(crpcamp.^n./(Kpca.^n+crpcamp.^n)).*(aracet.^n./(Kca.^n + aracet.^n)) ...
            + p_basal(ca) - degr_rates(ca)*c;
    end

end
