function out = stabIsocline

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%In this script we check the stability of the steady states               %
%reached by the system
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% Define parameters

clear all;
close all;

format long;

global arac ca gfp camp synt_rates Karac Kca Kpca kcat degr_rates diss_rates ...
    p_basal arabinose crp eta n

%index for the matrix

arac=1;
ca=2;
gfp=3;
camp=4;

%synthesis rates

synt_rates=zeros(3,1);%M.L-1.min-1

%equation of evolution of arac:
%crpcamp -> arac
%darac=synt_rates(arac)*crpcamp^n/(Karac^n+crpcamp^n) hill function
% -degr_rates(arac)*s(arac)                           degradation
%+p_basal(arac)                                        basal productio,

synt_rates(arac)=12*10^(-8); % value Elise: 6*10^(-10)

%equation of evolution of ca:
%crpcamp and aracet -> ca
%dca=synt_rates(ca)*crpcamp^n/(Kpca^n +
%crpcamp^n)*aracet^n/(Kca^n+aracet^n)        product of hill functions
%-degr_rates(ca)*s(ca)                        degradation
%+p_basal(ca)                                 basal production

%synt_rates(ca)=2*10^(-7);
synt_rates(ca)=2*10^(-9);

%threshold

Karac=0.3*10^(-6);%mol.L-1 %correspond to the activation of arac by crpcam
Kca=0.5*10^(-5);%corresponds to the activation of ca by arac
Kpca=0.6*10^(-6);%corresponds to the activation of ca by crpcamp 

%catalyse coefficient
%ca+atp -> ca atp -> ca +camp
%CAMP=kcat*s(ca)/degr_rates(camp)                catalyse procution by ca
%+eta*CAMPi/degr_rates(camp)                     camp out initial

kcat=6*135;%min-1


%Dissociation rates

diss_rates=zeros(2,1);%M-1.L.min-1

%here is the dissociation coefficient in the complexation of crp with camp
%camp + crp -> crpcamp
%crpcamp=crp*CAMP/(diss_rates(camp)+CAMP)
diss_rates(camp)=10^(-5);


%here is the dissociation coefficient of the complexation of arabinose 
% arac + arabinose -> aracet
%with arac
%aracet=s(arac)/(1+diss_rates(arac)/arabinose)
diss_rates(arac)=2*10^(-13);


%export/degradation rates

degr_rates=zeros(4,1);%min-1

degr_rates(arac)=6*10^(-3);
degr_rates(ca)=6*10^(-3); 
degr_rates(gfp)=6*10^(-3);
degr_rates(camp)=2.1;

%basal coefficients

p_basal=zeros(2,1);%M.L.min-1

p_basal(arac)=12*10^(-11);
p_basal(ca)=2*10^(-12);

%constant production

arabinose=10^(-4);%M.L-1
crp=10^(-6);

%quorum sensing coefficient %min-1
eta=6*10^(-1);

%hill cooperativity

n=1.5; 



%% Give the initial condition and solve the system of equations.


for j = 1:12 %iterate over external camp concentrations

    campext = 10^(-j);
    if j<7 %we know that for these values, 
        x0=[10^(-5) 10^(-7)];
    else
    [x0]=[10^(-5) 10^(-9)];
    end
    options=optimset('TolFun',1e-15,'MaxFunEvals',20000);
    [seq]=fsolve(@odeArac,x0,options);
    j
    seq
    
    %We want to  know if they are stable or not
    campint = kcat*seq(2)/degr_rates(camp)+ campext*eta/degr_rates(camp);
    crpcamp = ((diss_rates(camp) + campint + crp) ...
            - sqrt((diss_rates(camp) + campint + crp).^2 -4 * campint .* crp))/2;
    delta=(diss_rates(camp) + campint + crp).^2 -4 * campint .* crp;
    dcrpcampds2=(kcat/degr_rates(camp)-kcat*(diss_rates(camp)+campint...
        -crp)/(degr_rates(camp)*sqrt(delta)))/2;
    
    
    M=zeros(2);%this is the gradient matrix
    M(1,1)=-degr_rates(arac);
    M(1,2)=synt_rates(arac)*dcrpcampds2*Karac/(Karac+crpcamp);
    aracet=seq(1)./(1+diss_rates(arac)/arabinose);
    daracetds1=1/(1+diss_rates(arac)/arabinose);
    M(2,1)=synt_rates(ca)*crpcamp*Kca*daracetds1/((Kpca+crpcamp)*(Kca+aracet)^2);
    M(2,2)=synt_rates(ca)*aracet*Kpca*dcrpcampds2/((Kca+aracet)...
        *(Kpca+crpcamp)^2)-degr_rates(ca);
    
    [v,lambda]=eig(M)
    
end

%% Define differential equations

    function [f] = odeArac(s)

        campint = kcat*s(2)/degr_rates(camp)+ campext*eta/degr_rates(camp);
        crpcamp = ((diss_rates(camp) + campint + crp) ...
            - sqrt((diss_rates(camp) + campint + crp).^2 -4 * campint .* crp))/2;

        %crpcamp=campint;
        
        dadt = synt_rates(arac)*(crpcamp.^n./(Karac.^n+crpcamp.^n)) ...
            + p_basal(arac) - degr_rates(arac)*s(1);
   
        

        %crpcamp=campint;

        aracet=s(1)./(1+diss_rates(arac)/arabinose);
        %aracet=arabinose;

        dcdt = synt_rates(ca)*(crpcamp.^n./(Kpca.^n+crpcamp.^n)).*(aracet.^n./(Kca.^n + aracet.^n)) ...
            + p_basal(ca) - degr_rates(ca)*s(2);
        f=[dadt dcdt];
        
    end

end
